# Purpose

facilitates reading and exploring (visualizing) databases in [PhysioNet](https://physionet.org/)


# Other resources
- [LightWAVE (visualize)](https://physionet.org/lightwave/)
- TO add more...


# Updates
- 2021/01/21
LUDB (new version 1.0.1) finally corrects the errors related to units and ADC gains (ref. the `Release Notes` section of [this webpage](https://physionet.org/content/ludb/1.0.1/)).
